Information to display to the user about why a FromArgs construction exited early.
This can occur due to either failed parsing or a flag like --help.
Fields
output: StringThe output to display to the user of the commandline tool.
status: Result<(), ()>Status of argument parsing.
Ok if the command was parsed successfully and the early exit is due
to a flag like --help causing early exit with output.
Err if the arguments were not successfully parsed.